<?php

/**
 * Class-NotifyBoardReply.php
 *
 * @package NotifyBoardReply
 * @author PeakFox
 * @copyright 2022 PeakFox
 * @version 1.0b7 (31 January 2023)
 * @license https://spdx.org/licenses/GPL-3.0-or-later.html GPL-3.0-or-later
 */

namespace PeakFox;

final class NotifyBoardReply
{
	// @hook integrate_admin_areas
	// Add this mod's configuration panel to the admin menu
	//
	public static function adminAreas(array &$admin_areas) : void
	{
		global $txt;

		loadLanguage('NotifyBoardReply/lang');
		
		$admin_areas['config']['areas']['modsettings']['subsections']['NotifyBoardReply'] =
			[$txt['nbr_title']];
	}
	
	
	// @hook integrate_modify_modifications
	// Add settings to the configuration panel
	//	
	public static function prepSettings(array &$subActions) : void
	{
		$subActions['NotifyBoardReply'] = __CLASS__ . '::settings';
	}
	
	
	// Generate configuration settings for admin panel
	public static function settings($return_config = false)
	{
		global $context, $txt, $scripturl, $smcFunc;

		$context['post_url'] = $scripturl . '?action=admin;area=modsettings;save;sa=NotifyBoardReply';
		$context[$context['admin_menu_name']]['tab_data']['description'] = $txt['nbr_intro'];

		// Compose the configuration panel
		$context['settings_title'] = $txt['nbr_settings_title'];
		$config_vars = [
			['desc', 'nbr_desc']
		];
		
		// Generate a list of all boards and their selection status
		$req = $smcFunc['db_query']('', "
			SELECT
				id_board, name, mod_nbr_flag
			FROM
				{db_prefix}boards
			ORDER BY
				name
		");
		$boardList = $smcFunc['db_fetch_all']($req);
		$smcFunc['db_free_result']($req);	
		
		foreach ($boardList as $board)
		{
			$id = $board['id_board'];
			$config_vars[] = [
				'check', 'flag_'.$id, 
				'value' => $board['mod_nbr_flag'], 
				'label' => $board['name']
			];
		}
	
		// Return config vars
		if ($return_config)
			return $config_vars;
		
		// Save settings (= update board flags in DB)				
		if (isset($_REQUEST['save']))
		{
			checkSession();
			foreach ($boardList as $board)
			{
				$id = $board['id_board'];
				$flag = isset($_POST['flag_' . $id]) ? 1 : 0;
				$smcFunc['db_query']('', "
					UPDATE 
						{db_prefix}boards
					SET
						mod_nbr_flag = {int:flag}
					WHERE
						id_board = {int:id}",
					array(
						'flag' => $flag,
						'id' => $id
					)
				);
			}
		
			// Redirect to config panel
			redirectexit('action=admin;area=modsettings;sa=NotifyBoardReply');
		}
		
		prepareDBSettingContext($config_vars);
	}
	
	
	// @hook integrate_post2_end
	// Called during submission of a new post
	//
	public static function post2End() : void
	{
		global $smcFunc, $context, $topic, $board;
	
		// The "$newtopic" flag is not available as a global, so we check whether
		// $context['current_topic'] is zero instead

		if ($context['current_topic'] == 0)
		{
			// This only gets executed for new topics
			
			// Find all subscribers to the board which contains this topic
			$req = $smcFunc['db_query']('', "
				SELECT
					id_member, {int:id_topic} as id_topic, 0 as id_board
				FROM
					{db_prefix}log_notify as a, {db_prefix}boards as b
				WHERE 
					(b.id_board = {int:id_board})
					AND (b.mod_nbr_flag = 1)
					AND (a.id_board = b.id_board)
				",
				array(
					'id_board' => $board,
					'id_topic' => $topic
				)
			);
			$data = $smcFunc['db_fetch_all']($req);
			$smcFunc['db_free_result']($req);

			// Add all board subscribers to this topic's reply notifications
			$smcFunc['db_insert']('ignore',
				'{db_prefix}log_notify',
				array('id_member' => 'int', 'id_topic' => 'int', 'id_board' => 'int'),
				$data,
				array('id_member', 'id_topic', 'id_board')
			);
		}		
	}
}
